<?php

class LSP_SettingsController {
    public function __construct() {
        add_action('admin_init', array($this, 'save'));
        add_action( 'admin_enqueue_scripts', array($this, 'admin_enqueue_scripts') );
        add_filter('imincomelab_license_description_' . LSP_SLUG, array($this, 'license_description'), 10, 2);
    }

    function license_description($description, $license){
        if($license->has_feature('developer')){
            return 'Developer Edition';
        }
        return 'Standard Edition';
    }

    function admin_enqueue_scripts( $hook_suffix ) {
        wp_enqueue_style( 'wp-color-picker' );
        wp_enqueue_script( 'wp-color-picker' );
    }

    public function save() {

        if (!current_user_can('manage_options')) {
            return;
        }

        if (isset($_POST['action']) && $_POST['action'] == 'update' && isset($_GET['page']) && $_GET['page'] == LSP_SLUG) {
            $nonce = $_POST['_wpnonce'];
            if (!wp_verify_nonce($nonce, 'update')) {
                wp_die('Nice Try...');
            }

            $settings = LSP_LegalSuitePro::instance()->settings;
            $license = LSP_LegalSuitePro::instance()->license;

            if ($license->is_licensed()) {

                $post = stripslashes_deep($_POST);

                //save settings here
                $settings->site_name = $post['site_name'];
                $settings->site_url = $post['site_url'];
                $settings->support_url = $post['support_url'];
                $settings->state = $post['state'];

                $settings->enable_legal_page = isset($post['enable_legal_page']);
                if($settings->enable_legal_page) {
                    $settings->legal_page_path = $post['legal_page_path'];

                    foreach(LSP_Template::get_templates() as $template => $name){
                        $settings->$template = isset($post[$template]);
                    }
                }

                $settings->enable_cookie_bar = isset($post['enable_cookie_bar']);
                if($settings->enable_cookie_bar) {
                    $settings->cookie_bar_background_color = $post['cookie_bar_background_color'];
                    $settings->cookie_bar_text = $post['cookie_bar_text'];
                    $settings->cookie_bar_text_color = $post['cookie_bar_text_color'];
                    $settings->cookie_bar_button = $post['cookie_bar_button'];
                    $settings->cookie_bar_button_color = $post['cookie_bar_button_color'];
                }
            }
        }
    }

    public function render() {
        $settings = LSP_LegalSuitePro::instance()->settings;
        $license = LSP_LegalSuitePro::instance()->license;
        require LSP_VIEW_DIR . '/settings.php';
    }


}