<?php

namespace IMIncomeLab\WordPress\Controllers\v1_0;
use \Exception;

/**
 * Class OptionsPage
 * @package IMIncomeLab\src\WordPress\Controllers\v1_0
 */
class OptionsPage {
    /**
     * @var string
     */
    protected $page_title = 'Page Title';
    /**
     * @var string
     */
    protected $menu_title = 'Menu Title';
    /**
     * @var string
     */
    protected $slug = 'slug';
    /**
     * @var string
     */
    protected $capability = 'manage_options';

    /**
     * @var null
     */
    protected $view = null;

    /**
     * @var string
     */
    protected $success = 'Saved';
    /**
     * @var string
     */
    protected $error = 'An Error Occurred';

    /**
     * OptionsPage constructor.
     */
    public function __construct() {
        add_action('admin_init', array($this, 'handle_save'));
        add_action('admin_menu', array($this, 'admin_menu'));
        add_action('admin_notices', array($this, 'admin_notices'));
    }

    /**
     *
     */
    function admin_menu(){
        add_options_page(
            $this->page_title,
            $this->menu_title,
            $this->capability,
            $this->slug,
            array($this, 'render')
        );
    }

    /**
     *
     */
    public function admin_notices(){
        if(isset($_GET['page']) && $_GET['page'] == $this->slug && isset($_GET['success']) && isset($_GET['message'])){
            $success = stripslashes($_GET['success']);
            $message = stripslashes($_GET['message']);
            $class = ($success == '1' ? 'success' : 'error');

            ?>
                <div class="notice notice-<?php echo $class; ?> is-dismissible">
                    <p><?php echo $message; ?></p>
                </div>
            <?php
        }
    }

    /**
     * @throws Exception
     */
    public function handle_save() {

        if(!current_user_can($this->capability)) {
            return;
        }

        if(isset($_POST['action']) && $_POST['action'] == 'update' && isset($_GET['page']) && $_GET['page'] == $this->slug) {
            $nonce = $_POST['_wpnonce'];
            if (!wp_verify_nonce($nonce, 'update')) {
                wp_die('Nice Try...');
            }

            $config = stripslashes_deep($_POST);
            $parameters = stripslashes_deep($_GET);

            if($this->save($config)){
                $parameters['message'] = $this->success;
                $parameters['success'] = 1;
            }else{
                $parameters['message'] = $this->error;
                $parameters['success'] = 0;
            }

            $parts = explode('?', $_SERVER['REQUEST_URI']);
            $uri = $parts[0];
            $redirect = $uri . '?' . http_build_query($parameters);
            wp_redirect($redirect);
        }
    }

    /**
     * @throws Exception
     */
    public function render() {
        $options = $this->get_options();
        extract($options);
        require $this->view;
    }

    /**
     * @return array Array containing current options
     */
    public function get_options(){
        return array();
    }

    /**
     * @param $options
     * @return bool Result of save action
     */
    public function save($options){
        return false;
    }
}