<?php

namespace IMIncomeLab\WordPress\Model\v1_1;

use \Exception;

/**
 * Class Model
 * @package IMIncomeLab\WordPress\Model\v1_1
 */
class Model {

    //$options stores all our serializable fields
    /**
     * @var null
     */
    protected $properties = null;

    //$suspend_autosave is used to prevent auto saving
    /**
     * @var bool
     */
    protected $suspend_autosave = false;

    /**
     * @param $name
     * @param $value
     * @throws Exception
     */
    public function __set($name, $value) {
        $this->properties[$name] = $value;
        if ($this->suspend_autosave)
            return;

        $this->save();
    }

    /**
     * @param $name
     * @return mixed
     * @throws Exception
     */
    public function __get($name) {
        if (array_key_exists($name, $this->properties)) {
            return $this->properties[$name];
        }

        if (isset($this->default)) {
            if (array_key_exists($name, $this->default)) {
                return $this->default[$name];
            }
        }

        throw new Exception('Attempt to access non-existent property: ' . $name);
    }

    /**
     * @param $name
     * @return bool
     */
    public function __isset($name) {
        return isset($this->properties[$name]);
    }

    /**
     * @param $name
     */
    public function __unset($name) {
        unset($this->properties[$name]);
    }

    /**
     *
     */
    public function suspend_autosave() {
        $this->suspend_autosave = true;
    }

    /**
     * @throws Exception
     */
    public function resume_autosave(){
        $this->suspend_autosave = false;
        $this->save();
    }

    /**
     * @throws Exception
     */
    public function save() {
        throw new Exception('save() not implemented');
    }
}