<?php
    /**
     * Redux Framework is free software: you can redistribute it and/or modify
     * it under the terms of the GNU General Public License as published by
     * the Free Software Foundation, either version 2 of the License, or
     * any later version.
     * Redux Framework is distributed in the hope that it will be useful,
     * but WITHOUT ANY WARRANTY; without even the implied warranty of
     * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
     * GNU General Public License for more details.
     * You should have received a copy of the GNU General Public License
     * along with Redux Framework. If not, see <http://www.gnu.org/licenses/>.
     *
     * @package     ReduxFramework
     * @author      Dovy Paukstys
     * @version     3.1.5
     */
//Variable Define for server cloud and browser list

// Exit if accessed directly
    if ( ! defined( 'ABSPATH' ) ) {
        exit;
    }

// Don't duplicate me!
    if ( ! class_exists( 'ReduxFramework_import_export' ) ) {

        /**
         * Main ReduxFramework_import_export class
         *
         * @since       1.0.0
         */
        class ReduxFramework_import_export extends ReduxFramework {

            /**
             * Field Constructor.
             * Required - must call the parent constructor, then assign field and value to vars, and obviously call the render field function
             *
             * @since       1.0.0
             * @access      public
             * @return      void
             */
            function __construct( $field = array(), $value = '', $parent ) {

                $this->parent   = $parent;
                $this->field    = $field;
                $this->value    = $value;
                $this->is_field = $this->parent->extensions['import_export']->is_field;

                $this->extension_dir = ReduxFramework::$_dir . 'inc/extensions/import_export/';
                $this->extension_url = ReduxFramework::$_url . 'inc/extensions/import_export/';

                // Set default args for this field to avoid bad indexes. Change this to anything you use.
                $defaults    = array(
                    'options'          => array(),
                    'stylesheet'       => '',
                    'output'           => true,
                    'enqueue'          => true,
                    'enqueue_frontend' => true
                );
                $this->field = wp_parse_args( $this->field, $defaults );

            }

            /**
             * Field Render Function.
             * Takes the vars and outputs the HTML for the field in the settings
             *
             * @since       1.0.0
             * @access      public
             * @return      void
             */
            public function render() {

                $secret = md5( md5( AUTH_KEY . SECURE_AUTH_KEY ) . '-' . $this->parent->args['opt_name'] );

                // No errors please
                $defaults = array(
                    'full_width' => true,
                    'overflow'   => 'inherit',
                );

                $this->field = wp_parse_args( $this->field, $defaults );

                $bDoClose = false;

                // $this->parent->args['opt_name'] & $this->field['id'] are sanitized in the ReduxFramework class, no need to re-sanitize it.
                $id = $this->parent->args['opt_name'] . '-' . $this->field['id'];

                // $this->field['type'] && $this->field['id'] is sanitized in the ReduxFramework class, no need to re-sanitize it.
                ?>
                    <h1 id='demo_importer_title_codersaiful'><?php esc_html_e( 'LGS Optin Import and Export', 'redux-framework' ); ?></h1>
                    <div id="demo_importer_by_codersaiful">
                        <p style="background: #62d8ff;padding: 5px;border: #aaa;margin:0 0 10px 0;color: #333;">
                            LGS Optin Theme is part of our LeadGenSiteProfits.com offer with over 50 pre-made lead-gen site PLR packages.
                        </p>
                        <h2>LGS Optin Import</h2>
                        <!-- Developed by: Saiful Islam <codersaiful@gmail.com> -->
                        <input value="0" type="hidden" class="large-text noUpdate" id="import-link-value" name="<?php echo $this->parent->args['opt_name'] ?>[import_link]">
                        <p> 
                            <label>Access Key. This was delivered to you in the ‘Thank You’ email we sent after your purchase. You can also find it inside the members area.</label>
                            <input id="codersaiful_access_key" style="padding: 10px;color: green;font-size: 17px;" type="text" class="large-text noUpdate" value="" placeholder="Enter Your Access Key Here">
                        </p>
                        <select id='codersaiful_import_link'>
                            <option value="0">Select LGS Optin Site</option>
                        </select>
                        <input class="button-secondary" type="button" id='codersaiful_demo_import_button' name="import" value="Import">
                    </div>
                    <?php
                    //*****************************
                    ?>
                    
                    <h3>Import Options</h3>
                    <p>
                        Import LGS Optin Site from your computer.
                    </p>
                    <p>
                        <input type="file" id="json_import_lgs">
                        <!--
                        <a href="javascript:void(0);" id="redux-import-code-button" class="button-secondary">
                            <?php esc_html_e( 'Import from computer', 'redux-framework' ); ?>
                        </a>
                        
                        <a href="javascript:void(0);" id="redux-import-link-button" class="button-secondary">
                            <?php esc_html_e( 'Import from URL', 'redux-framework' ) ?>
                        </a>
                        -->
                    </p>
                    
                    <div style="display: none !important;" id="redux-import-code-wrapper">
                        <p class="description" id="import-code-description">
                            <?php echo esc_html( apply_filters( 'redux-import-file-description', __( 'Input your backup file below and hit Import to restore your sites options from a backup.', 'redux-framework' ) ) ); ?>
                        </p>
                        <?php // $this->parent->args['opt_name'] is sanitized in the ReduxFramework class, no need to re-sanitize it. ?>
                        <textarea id="import-code-value" name="<?php echo $this->parent->args['opt_name']; ?>[import_code]" class="large-text noUpdate" rows="2"></textarea>
                    </div>

                    <div id="redux-import-link-wrapper">
                        <p class="description" id="import-link-description"><?php echo esc_html( apply_filters( 'redux-import-link-description', __( 'Input the URL to another sites options set and hit Import to load the options from that site.', 'redux-framework' ) ) ); ?></p>
                        <?php // $this->parent->args['opt_name'] is sanitized in the ReduxFramework class, no need to re-sanitize it. ?>
                        <textarea class="large-text noUpdate" id="import-link-value" name="" rows="2"></textarea>
                    </div>
                    
                    
                    <p id="redux-import-action"><input type="submit" id="redux-import" name="import" class="button-primary" value="<?php esc_html_e( 'Import', 'redux-framework' ) ?>">&nbsp;&nbsp;<span><?php echo esc_html( apply_filters( 'redux-import-warning', __( 'WARNING! This will overwrite all existing option values, please proceed with caution!', 'redux-framework' ) ) ) ?></span></p>
                    
                    <div class="hr"/>
                    <div class="inner"><span>&nbsp;</span></div></div>
                    <hr>
                    <h4><?php esc_html_e( 'Export Options', 'redux-framework' ) ?></h4>

                    <div class="redux-section-desc">
                        <p class="description">
                            <?php echo esc_html( apply_filters( 'redux-backup-description', __( 'Export your own LGS created site.', 'redux-framework' ) ) ) ?>
                        </p>
                    </div>
                <?php
                // $this->parent->args['opt_name'] is sanitized in the ReduxFramework class, no need to re-sanitize it.
                $link = esc_url( admin_url( 'admin-ajax.php?action=redux_download_options-' . $this->parent->args['opt_name'] . '&secret=' . $secret ) );
                ?>
                    <p>
                        <!-- <a href="javascript:void(0);" id="redux-export-code-copy" class="button-secondary"><?php esc_html_e( 'Copy Data', 'redux-framework' ) ?></a> -->
                        <a href="<?php echo $link; ?>" id="redux-export-code-dl" class="button-primary"><?php esc_html_e( 'Download LGS', 'redux-framework' ) ?></a>
                        <!-- <a href="javascript:void(0);" id="redux-export-link" class="button-secondary"><?php esc_html_e( 'Copy Export URL', 'redux-framework' ) ?></a> -->
                    </p>

                    <p></p>
                    <textarea class="large-text noUpdate" id="redux-export-code" rows="2"></textarea>
                    <textarea class="large-text noUpdate" id="redux-export-link-value" data-url="<?php echo $link; ?>" rows="2"><?php echo $link; ?></textarea>
                    
                    <!-- --->
                    <?php
                    $demo_site_link = 'https://controlleroptin.lgstheme.com/';//Obviously with right slash
                    //$demo_site_link = 'http://controller.lgstheme.com/';//Obviously with right slash
                    $list_browse_list_demo = $demo_site_link . 'demo-browse.php';
                    $cloud_root = $demo_site_link . 'demo.php?access_token='; //aSDGGESsdfdkd8df7vbDsk&demo_id=
                    //$cloud_root = $demo_site_link . 'demo.php?access_token=aSDGGESsdfdkd8df7vbDsk&demo_id=';
                    //var_dump($cloud_root);
                    ?>
                    <script type="text/javascript">

                        (function($) {
                            $(document).ready(function() {
                                /**
                                 * For json Importing to textArea
                                 */
                                $("#json_import_lgs").change(function(evt){
                                    var file = evt.target.files[0];
                                    if (file) {
                                        var read = new FileReader();
                                        read.onload = function(e) {
                                            console.log(e);
                                            var contents = e.target.result;
                                            $('#import-code-value').html(contents);
                                        }
                                        read.readAsText(file);
                                    }
                                });
                                //Demo list Load from json file.
                                //var list_browse_list_demo = 'http://localhost/project/theme_controller/demo-browse.php'; By: codersaiful@gmail.com
                                var list_browse_list_demo = '<?php echo $list_browse_list_demo; ?>';
                                console.log(list_browse_list_demo);
                                //Trying new
                                $.ajax({
                                    type: "GET",
                                    url: list_browse_list_demo,
                                    dataType: "jsonp", 
                                    success: function(data){
                                        console.log(data);
                                    },
                                    error : function(data){
                                              console.log(data);
                                             }
                                });
                                
                                //Trying End here
                                
                                
                                
                                $('#codersaiful_demo_import_button').hide();
                                var html_option = '<option value="0">Select LGS Site</option>';
                                $.getJSON(list_browse_list_demo)
                                        .done(function(done_deta){

                                            done_deta.forEach(function(per_demo_list){
                                                html_option += '<option value="'+per_demo_list.id+'">'+per_demo_list.title+'</option>';
                                                //console.log(per_demo_list.title);
                                            });
                                            $('#codersaiful_import_link').html(html_option);
                                            $('#codersaiful_demo_import_button').fadeIn(8000);
                                            console.log(done_deta);
                                        })
                                        .fail(function(fail_data){
                                            $('#codersaiful_import_link').hide();
                                            //$('#codersaiful_demo_import_button').fadeIn(2000);
                                            alert("There is no Demo");
                                            //console.log(fail_data);
                                        });
                                
                                
                                //Demo import by Click
                                $('#codersaiful_demo_import_button').click(function() {
                                    //var cloud_root = 'http://localhost/project/theme_controller/demo.php?access_token=aSDGGESsdfdkd8df7vbDsk&demo_id=';
                                    var cloud_root = '<?php echo $cloud_root; ?>';
                                    var full_cloud_link = false;
                                    var access_key = $('#codersaiful_access_key').val();
                                    
                                    if(access_key.length < 5){
                                        alert('Access key Invalid/Blank');
                                        $('#import-link-value').val(0);
                                        full_cloud_link = false;
                                    }else{
                                        var import_link_codersaiful = $('#codersaiful_import_link').val();
                                        if(import_link_codersaiful != 0){
                                            full_cloud_link = cloud_root + access_key + '&demo_id=' + import_link_codersaiful;
                                            console.log('access_key');
                                            console.log(full_cloud_link);
                                            $('#import-link-value').val(full_cloud_link);
                                        }else{
                                            $('#import-link-value').val(0);
                                            full_cloud_link = false;
                                        }
                                    }
                                   
                                    
                                    
                                    
                                    if(full_cloud_link){
                                        $.getJSON(full_cloud_link)
                                            .done(function(d) {
                                                var confirmation_submit = confirm('Are you Sure? \nCurrent all data will restore with selected demo.\nImport with your own risk. Just click ok to import.');
                                                if(confirmation_submit){
                                                    $('#redux-form-wrapper').submit();
                                                }else{
                                                    alert("Demo import Cancelled. Thanks");
                                                }
                                            })
                                            .fail(function(d) {
                                              alert("Invalid json or Security Key is Invalid!");
                                            });
                                         //$('#redux-form-wrapper').submit();
                                    }else{
                                        //alert('Something went wrong!');
                                        return false;
                                    }
                                    
                                });
                            });
                        })(jQuery);

                    </script>
                    <!--------------------->
                    
                    
                <?php
                // codersaiful import off here end here codersaiful */
            }

            /**
             * Enqueue Function.
             * If this field requires any scripts, or css define this function and register/enqueue the scripts/css
             *
             * @since       1.0.0
             * @access      public
             * @return      void
             */
            public function enqueue() {

                wp_enqueue_script(
                    'redux-import-export',
                    $this->extension_url . 'import_export/field_import_export' . Redux_Functions::isMin() . '.js',
                    array( 'jquery' ),
                    ReduxFramework_extension_import_export::$version,
                    true
                );

                wp_enqueue_style(
                    'redux-import-export',
                    $this->extension_url . 'import_export/field_import_export.css',
                    time(),
                    true
                );

            }

            /**
             * Output Function.
             * Used to enqueue to the front-end
             *
             * @since       1.0.0
             * @access      public
             * @return      void
             */
            public function output() {

                if ( $this->field['enqueue_frontend'] ) {

                }

            }

        }
    }
