<?php

	class InstallationController extends BaseController {

		public function configure_db() {

			$rules = array(
				'license_key'      => 'required',
				'host'             => 'required',
				'db_name'          => 'required',
				'db_user'          => 'required',
				'db_password'      => 'required',
				'email'            => 'required|email',
				'user_password'    => 'required|min:6',
				'confirm_password' => 'required|same:user_password'
			);

			/** @var Validator $validator */
			$validator = Validator::make( Input::all(), $rules );
			if( $validator->fails() ) {
				return Redirect::back()->withErrors( $validator )->withInput();
			}

			try {
				Config::set( "database.connections.mysql.driver", "mysql" );
				Config::set( "database.connections.mysql.host", Input::get( "host" ) );
				Config::set( "database.connections.mysql.database", Input::get( "db_name" ) );
				Config::set( "database.connections.mysql.username", Input::get( "db_user" ) );
				Config::set( "database.connections.mysql.password", Input::get( "db_password" ) );

				DB::connection()->getDatabaseName();

				$user = $this->rebrander->checkLicense( Input::get( 'license_key' ), Input::get( 'email' ), Input::get( 'user_password' ) );

				try {
					Artisan::call( 'migrate', array( '--force' => true ) );
				} catch( Exception $e ) {
					Artisan::call( 'migrate' );
				}

				$localhost = Input::get( 'host' ) ? Input::get( 'host' ) : 'localhost';
				$database  = Input::get( 'db_name' );
				$username  = Input::get( 'db_user' );
				$password  = Input::get( 'db_password' );

				#Read Database Sample file
				$file      = ".env.php";
				$app_debug = false;

				if( !file_exists( $file ) ) {
					$str = "<?php
return [
	'APP_DEBUG'     => ".( $app_debug ? "true" : "false" ).",
	'DB_CONNECTION' => 'mysql',
	'DB_PORT'       => 3306,
	'DB_HOST'       => '{dbhost}',
	'DB_DATABASE'   => '{dbdatabase}',
	'DB_USERNAME'   => '{dbusername}',
	'DB_PASSWORD'   => '{dbpassword}',
];
";
					file_put_contents( $file, $str );
				}

				$getDBConfig = file_get_contents( $file );
				$getDBConfig = str_replace( '{dbhost}', $localhost, $getDBConfig );
				$getDBConfig = str_replace( '{dbdatabase}', $database, $getDBConfig );
				$getDBConfig = str_replace( '{dbusername}', $username, $getDBConfig );
				$getDBConfig = str_replace( '{dbpassword}', $password, $getDBConfig );

				#Update content file
				file_put_contents( $file, $getDBConfig );

				// validation has passed, save user in DB
				$user                 = new User;
				$user->email          = Input::get( 'email' );
				$user->remember_token = "";
				$user->password       = Hash::make( Input::get( 'user_password' ) );

				$user->save();
			} catch( PDOException $e ) {
				$error = $e->getMessage();
				switch( $e->getCode() ) {
					case 1049:
						$error = "Unknown database '".Input::get( 'db_name' )."'";
						break;
					case 2005:
						$error = "Unknown MySQL server host '".Input::get( 'host' )."'";
						break;
					case 1045:
						$error = "Access denied for user '".Input::get( 'db_user' )."'@'".Input::get( 'host' )."'";
						break;
				}

				return Redirect::back()->withErrors( new \Illuminate\Support\MessageBag( [ "errors" => $error ] ) )->withInput();
			} catch( Exception $e ) {
				$errors = new \Illuminate\Support\MessageBag( [ "errors" => $e->getMessage() ] );

				return Redirect::back()->withErrors( $errors )->withInput();
			}

			return Redirect::to( '/' );
		}

		public function configure_mail() {

			#validate EMAIL and PASSWORD
			if( ( Input::get( 'host' ) == '' ) || ( Input::get( 'username' ) == '' ) || ( Input::get( 'password' ) == '' ) ) {
				$notification[] = array(
					'message' => Lang::get( 'Host, Username and Password Required' ),
					'type'    => 'error',
					'timeout' => '10'
				);
				Session::flash( 'notification', $notification );

				return Redirect::back()->withInput();
			}
			$host     = Input::get( 'host' );
			$port     = Input::get( 'port' );
			$username = Input::get( 'username' );
			$password = Input::get( 'password' );

			#Read Mail Sample file
			$getMailConfig = file_get_contents( __DIR__.'/../config/mail.sample.php' );
			$getMailConfig = str_replace( '{host}', $host, $getMailConfig );
			if( $port != '' ) {
				$getMailConfig = str_replace( '{port}', $port, $getMailConfig );
			} else {
				$getMailConfig = str_replace( '{port}', 587, $getMailConfig );
			}
			$getMailConfig = str_replace( '{username}', $username, $getMailConfig );
			$getMailConfig = str_replace( '{address}', $username, $getMailConfig );
			$getMailConfig = str_replace( '{password}', $password, $getMailConfig );
			#Update content file
			file_put_contents( __DIR__.'/../config/mail.php', $getMailConfig );

			return Redirect::to( '/' );
		}
	}
