<?php

	class ProfileController extends BaseController {

		/*
		 * Load default profile page
		 */
		public function index() {
			$user = Auth::user();

			return View::make( 'main' )
			           ->with( "support_email", $this->rebrander->getSupportEmail() )
			           ->with( "footer", $this->rebrander->getProductFooter() )
			           ->with( "logo", $this->rebrander->getProductLogo() )
			           ->with( "version", $this->rebrander->getVersion() )
			           ->with( "name", $this->rebrander->getProductName() )
			           ->with( 'page', 'profile' )
			           ->with( 'user', $user );
		}

		/*
		 * Update profile
		 */
		public function update() {

			$rules = array(
				'email' => 'required'
			);
			$v     = Validator::make( Input::all(), $rules );
			if( $v->fails() ) {
				return Redirect::to( 'profile' )->withErrors( $v );
			} else {
				$user = User::where( 'id', Auth::user()->id )->first();
				try {
					$this->rebrander->changeEmail( $user->email, Input::get( "email" ) );
				} catch( Exception $e ) {
					$notification[] = array(
						'message' => $e->getMessage(),
						'type'    => 'error',
						'timeout' => '10'
					);
					Session::flash( 'notification', $notification );

					return Redirect::to( 'profile' );
				}

				$GetResponse = User::where( 'id', Auth::user()->id )->update( array(
					'email' => Input::get( 'email' )
				) );

				if( $GetResponse ) {
					$notification[] = array(
						'message' => 'Successfully Updated',
						'type'    => 'success',
						'timeout' => '10'
					);
					Session::flash( 'notification', $notification );

					return Redirect::to( 'profile' );
				} else {

					$notification[] = array(
						'message' => 'Oops ! Something went wrong',
						'type'    => 'error',
						'timeout' => '10'
					);
					Session::flash( 'notification', $notification );

					return Redirect::to( 'profile' );
				}
			}
		}

		/*
		 * Change password
		 */
		public function changePassword() {

			$rules = array(
				'password'         => 'required|min:5',
				'confirm_passowrd' => 'required|same:password'
			);
			$v     = Validator::make( Input::all(), $rules );
			if( $v->fails() ) {
				return Redirect::to( 'profile' )->withErrors( $v );
			} else {
				$user = User::where( 'id', Auth::user()->id )->first();
				try {
					$this->rebrander->changePassword( $user->email, Input::get( 'password' ) );
				} catch( Exception $e ) {
					$notification[] = array(
						'message' => $e->getMessage(),
						'type'    => 'error',
						'timeout' => '10'
					);
					Session::flash( 'notification', $notification );

					return Redirect::to( 'profile' );
				}

				$GetResponse = User::where( 'id', Auth::user()->id )->update( array( 'password' => Hash::make( Input::get( 'password' ) ) ) );
				if( $GetResponse ) {
					$notification[] = array(
						'message' => 'Successfully Updated',
						'type'    => 'success',
						'timeout' => '10'
					);
					Session::flash( 'notification', $notification );

					return Redirect::to( 'profile' );
				} else {

					$notification[] = array(
						'message' => 'Oops ! Something went wrong',
						'type'    => 'error',
						'timeout' => '10'
					);
					Session::flash( 'notification', $notification );

					return Redirect::to( 'profile' );
				}
			}
		}
	}
