<?php

	use Config;

	class RemindersController extends BaseController {

		/**
		 * Display the password reminder view.
		 *
		 * @return Response
		 */
		public function getRemind() {
			return View::make( 'password.remind' )->with( "version", $this->rebrander->getVersion() );
		}

		/**
		 * Handle a POST request to remind a user of their password.
		 *
		 * @return Response
		 */
		public function postRemind() {

			Config::set( "mail.driver", "smtp" );
			Config::set( "mail.host", $this->rebrander->getSmtpHost() );
			Config::set( "mail.port", $this->rebrander->getSmtpPort() );
			Config::set( "mail.username", $this->rebrander->getSmtpUsername() );
			Config::set( "mail.password", $this->rebrander->getSmtpPassword() );
			Config::set( "mail.encryption", $this->rebrander->getProtocol() );
			Config::set( "mail.from.address", $this->rebrander->getFromEmail() );
			Config::set( "mail.from.name", $this->rebrander->getFrom() );

			extract( Config::get( 'mail' ) );

			// create new mailer with new settings
			$transport = Swift_SmtpTransport::newInstance( $host, $port );
			// set encryption
			if( isset( $encryption ) ) {
				$transport->setEncryption( $encryption );
			}
			// set username and password
			if( isset( $username ) ) {
				$transport->setUsername( $username );
				$transport->setPassword( $password );
			}
			// set new swift mailer
			Mail::setSwiftMailer( new Swift_Mailer( $transport ) );
			// set from name and address
			if( is_array( $from ) && isset( $from[ 'address' ] ) ) {
				Mail::alwaysFrom( $from[ 'address' ], $from[ 'name' ] );
			}

			try {
				$requestEmail = Input::only( "email" );
				$email        = $requestEmail[ 'email' ];
				$client       = User::where( "email", "=", $email )->first();
				if( !$client ) {
					$ruser = $this->rebrander->getClient( $email );

					$user = User::firstOrNew( array( 'email' => $email ) );
					$user->save();
				}
			} catch( \Exception $e ) {
				switch( $e->getCode() ) {
					case 560:
						return Redirect::back()->with( 'error', Lang::get( 'reminders.user' ) );
					default:
						return Redirect::back()->with( 'error', $e->getMessage() );
				}
			}

			$response = Password::remind( $requestEmail, function ( $message ) {
				$message->subject( 'Password Reminder' );
			} );

			switch( $response ) {
				case Password::INVALID_USER:
					return Redirect::back()->with( 'error', Lang::get( $response ) );

				case Password::REMINDER_SENT:
					return Redirect::back()->with( 'status', Lang::get( $response ) );
			}
		}

		/**
		 * Display the password reset view for the given token.
		 *
		 * @param  string $token
		 *
		 * @return Response
		 */
		public function getReset( $token = null ) {
			if( is_null( $token ) ) {
				App::abort( 404 );
			}

			return View::make( 'password.reset' )->with( "logo", $this->rebrander->getProductLogo() )->with( "name", $this->rebrander->getProductName() )->with( 'token', $token );
		}

		/**
		 * Handle a POST request to reset a user's password.
		 *
		 * @return Response
		 */
		public function postReset() {
			$credentials = Input::only( 'email', 'password', 'password_confirmation', 'token' );

			$response = Password::reset( $credentials, function ( $user, $password ) {
				try {
					$this->rebrander->changePassword( $user->email, $password );
				} catch( Exception $e ) {
					return Redirect::back()->with( 'error', Lang::get( 'reminders.reseterror' ) );
				}

				$user->password = Hash::make( $password );

				$user->save();
			} );

			switch( $response ) {
				case Password::INVALID_PASSWORD:
				case Password::INVALID_TOKEN:
				case Password::INVALID_USER:
					return Redirect::back()->with( 'error', Lang::get( $response ) );

				case Password::PASSWORD_RESET:
					return Redirect::to( '/' );
			}
		}
	}
