(function () {
	var StripeBilling = {
		init: function () {
			this.form = $("#billing-form");
			this.submitButton = $(".bigOrderBTN");
			this.submitButtonOriginalColour = this.submitButton.css("background-color");
			this.submitButtonEnabled = true;
			this.month = 1;
			this.year = 2015;

			var stripeKey = $('meta[name=publishable_key]').attr("content");
			Stripe.setPublishableKey(stripeKey);

			this.bindEvents();
		},

		bindEvents: function () {
			this.submitButton.on("click", $.proxy(this.addStripFields, this));
			this.form.on("submit", $.proxy(this.sendToken, this));
		},

		validateFields: function () {

			var errors = [];
			if ($("#userFirstName").val().length == 0) {
				errors.push("First name field is required");
			}

			if ($("#userLastName").val().length == 0) {
				errors.push("Last name field is required");
			}

			if ($("#userEmail").val().length == 0) {
				errors.push("Last name field is required");
			}

			if ($("#userPassword").val().length == 0) {
				errors.push("Password field is required");
			}

			if ($("#userRetypePassword").val().length == 0) {
				errors.push("Retype password field is required");
			}

			if ($("#userPassword").val().length > 0 && $("#userRetypePassword").val().length > 0 && $("#userPassword").val() != $("#userRetypePassword").val()) {
				errors.push("Password mismatch");
			}

			if (!$("[name='package']:checked").val()) {
				errors.push("Package field is required");
			}

			if ($("#gateway").val() == "stripe") {
				this.splitExpiryDate();
				if ($("#ccNum").val().length == 0) {
					errors.push("Credit card number field is required");
				} else if (!Stripe.card.validateCardNumber($("#ccNum").val())) {
					errors.push("Your credit card number is invalid");
				}

				var expiryDate = $("#ccExpire").val().split("/");
				var month = parseInt(expiryDate[0]);
				var year = parseInt(expiryDate[1]);

				if ($("#ccExpire").val().length == 0) {
					errors.push("Credit card expiration date field is required");
				} else if (!Stripe.card.validateExpiry(this.month, this.year)) {
					errors.push("Your credit card expiry date is invalid.");
				}

				if ($("#ccCSV").val().length == 0) {
					errors.push("CVV Code field is required");
				} else if (!Stripe.card.validateCVC($("#ccCSV").val())) {
					errors.push("Your credit card security code is invalid");
				}

				//if ($("#address").val().length == 0) {
				//	errors.push("Address field is required");
				//}
				//
				//if ($("#country").val().length == 0) {
				//	errors.push("Country field is required");
				//}
				//
				//if ($("#state").val().length == 0) {
				//	errors.push("State field is required");
				//}
				//
				//if ($("#city").val().length == 0) {
				//	errors.push("City field is required");
				//}
				//
				//if ($("#zip").val().length == 0) {
				//	errors.push("Zip field is required");
				//}
			}

			if (errors.length > 0) {
				this.showError(errors);
				return false;
			}
			return true;
		},

		addStripFields: function () {
			if (this.submitButtonEnabled) {
				if (this.validateFields()) {
					this.submitButton.css("background-color", "#BCBCBC");
					this.submitButtonEnabled = false;
					if ($("#gateway").val() == "stripe") {
						if ($("#exp_month").length > 0) {
							$("#exp_month").val(this.month);
						} else {
							$("<input>").attr({
								type: "hidden",
								id: "exp_month",
								'data-stripe': "exp_month",
								value: this.month
							}).appendTo(this.form);
						}

						if ($("#exp_year").length > 0) {
							$("#exp_yeaer").val(this.year);
						} else {
							$("<input>").attr({
								type: "hidden",
								id: "exp_year",
								'data-stripe': "exp_year",
								value: this.year
							}).appendTo(this.form);
						}

						this.form.submit();
					} else {
						this.form[0].submit();
					}
				}
			}
		},

		splitExpiryDate: function () {
			var expiryDate = $("#ccExpire").val().split("/");
			this.month = parseInt(expiryDate[0]);
			this.year = parseInt(expiryDate[1]);
		},

		sendToken: function (e) {

			Stripe.card.createToken(this.form, $.proxy(this.stripeResponseHandler, this));

			e.preventDefault();

		},

		stripeResponseHandler: function (status, response) {
			if (response) {
				if (response.error) {
					this.showError(response.error.message);
					return;
				}

				$("<input>").attr({
					type: "hidden",
					name: "stripeToken",
					value: response.id
				}).appendTo(this.form);

				this.form[0].submit();

			}
		},

		showError: function (message) {
			var error = $(".errors");
			error.empty();
			$("<ul>").attr({
				id: "error_ul"
			}).appendTo(error);
			if (message instanceof Array) {
				$.each(message, function (key, value) {
					$("<li>").html(value).appendTo("#error_ul");
				});
			} else {
				$("<li>").html(message).appendTo("#error_ul");
			}
			error.css("display", "block");
			$("html, body").animate({scrollTop: 0}, "slow");
			this.submitButtonEnabled = true;
			this.submitButton.css("background-color", this.submitButtonOriginalColour);
		}
	};

	StripeBilling.init();
})();