<?php
	/**
	 * Created by PhpStorm.
	 * User: Alex
	 * Date: 07-01-2015
	 * Time: 13:50
	 */
	require_once( "sdk_config.php" );
	require_once( "curl.php" );

	/**
	 * Class RebranderSDK
	 */
	class RebranderSDK {

		/**
		 * @var int
		 */
		protected $hash_cost = 10;

		/**
		 * @var Curl
		 */
		protected $curl;

		/**
		 * @var string
		 */
		protected $command;

		/**
		 * @var array
		 */
		protected $params;

		/**
		 * @var object
		 */
		protected $options;

		/**
		 * @var object
		 */
		protected $user;

		/**
		 * @return mixed
		 */
		public function setOptions( $options ) {
			$this->options = $options;
		}

		/**
		 * @return mixed
		 */
		public function getOptions() {
			return $this->options;
		}

		/**
		 * @return mixed
		 */
		public function getUser() {
			return $this->user;
		}

		/**
		 * @return mixed
		 */
		public function getUserFirtName() {
			if( $this->user ) {
				return $this->user->first_name;
			}

			return "";
		}

		/**
		 * @return mixed
		 */
		public function getUserLastName() {
			if( $this->user ) {
				return $this->user->last_name;
			}

			return "";
		}

		/**
		 * @return mixed
		 */
		public function getUserFullName() {
			if( $this->user ) {
				return $this->user->full_name;
			}

			return "";
		}

		/**
		 * @return mixed
		 */
		public function getUserEmailAddress() {
			if( $this->user ) {
				return $this->user->email;
			}

			return "";
		}

		/**
		 *
		 */
		public function __construct() {
			$this->curl = new Curl( API_URL );
		}

		/****************************** License Functions *******************************/
		/**
		 * @param $license_key
		 * @param $email_address
		 * @param $password
		 *
		 * @return mixed
		 * @throws Exception
		 */
		public function checkLicense( $license_key, $email_address, $password ) {
			return $this->send( "license", array( "license" => $license_key, "email" => $email_address, "password" => $password ) );
		}

		/****************************** Login/User Functions *******************************/
		/**
		 * @param $email_address
		 * @param $password
		 *
		 * @return mixed
		 * @throws Exception
		 */
		public function checkLogin( $email_address, $password ) {
			return $this->send( "login", array( "email" => $email_address, "password" => $password ) );
		}

		/**
		 * @param      $email_address
		 * @param      $new_password
		 * @param bool $old_password
		 *
		 * @return mixed
		 * @throws Exception
		 */
		public function changePassword( $email_address, $new_password, $old_password = false ) {
			$params = array( "email" => $email_address, "new_password" => $new_password );
			if( $old_password ) {
				$params[ "old_password" ] = $old_password;
			}

			return $this->send( "changepassword", $params, false );
		}

		/**
		 * @param $old_email
		 * @param $new_email
		 *
		 * @return mixed
		 * @throws Exception
		 */
		public function changeEmail( $old_email, $new_email ) {
			return $this->send( "changeemail", array( "old_email" => $old_email, "new_email" => $new_email ), false );
		}

		/****************************** Version Functions *******************************/
		public function showVersion() {
			if( defined( "APP_VERSION" ) ) {
				$result = $this->send( "checkversion", array( "version" => APP_VERSION ) );
				if( $result->version !== false ) {
					$dir = dirname( __FILE__ );
					if( file_exists( "{$dir}/../rebrander-sdk" ) ) {
						require_once( "{$dir}/../checkout/include/functions.php" );
					} else {
						require_once( "{$dir}/../../checkout/include/functions.php" );
					}

					return '<link rel="stylesheet" href="'.siteURL( true, true, false, true ).'rebrander-sdk/css/style.css" />
					<div id="gritter-notice-wrapper">
						<div style="" class="gritter-item-wrapper" id="gritter-item-1">
							<div class="gritter-top"></div>
							<div class="gritter-item">
								<div class="gritter-close" style="display: block;" onclick="javascript:document.getElementById(\'gritter-notice-wrapper\').remove();"></div>
								<div class="gritter-without-image"><span class="gritter-title">New Version Available!</span>
									<p><u><a style="color:#ccc" href="'.siteURL( true, true, false, true ).'rebrander-sdk/download.php">Update automatically</a></u></p></div>
								<div style="clear:both"></div>
							</div>
							<div class="gritter-bottom"></div>
						</div>
					</div>';
				}
			}

			return '';
		}

		/**
		 * @return string
		 */
		public function getVersion() {
			return APP_VERSION;
		}

		/**
		 * @return mixed
		 * @throws Exception
		 */
		public function downloadNewVersion() {
			return $this->send( "downloadversion" );
		}

		/**
		 * @return mixed
		 * @throws Exception
		 */
		public function getClients() {
			return $this->send( "getclients" );
		}

		/****************************** Rebander App Options *******************************/
		public function getRebranderAppId() {
			return $this->fetchRebranderAppOptions( "id" );
		}

		/**
		 * @return mixed
		 */
		public function getLicense() {
			return $this->fetchRebranderAppOptions( "license" );
		}

		/**
		 * @return mixed
		 */
		public function getRebranderAppStatus() {
			return $this->fetchRebranderAppOptions( "status" );
		}

		/*********************************** App Options ***********************************/
		public function getAppId() {
			return $this->fetchAppOptions( "id" );
		}

		/**
		 * @return mixed
		 */
		public function getName() {
			return $this->fetchAppOptions( "name" );
		}

		/**
		 * @return mixed
		 */
		public function getThumbnail() {
			return $this->fetchAppOptions( "thumbnail" );
		}

		/**
		 * @return mixed
		 */
		public function getDescription() {
			return $this->fetchAppOptions( "description" );
		}

		/**
		 * @return mixed
		 */
		public function getCode() {
			return $this->fetchAppOptions( "code" );
		}

		/**
		 * @return mixed
		 */
		public function getPlan() {
			return $this->fetchAppOptions( "plan" );
		}

		/**
		 * @return mixed
		 */
		public function getAppStatus() {
			return $this->fetchAppOptions( "status" );
		}

		/***************************** Auto Responder Settings *****************************/
		public function getAutoResponderHtml() {
			return $this->fetchAutoResponderSettings( "html_code" );
		}

		/**
		 * @return mixed
		 */
		public function getAutoResponderFirstName() {
			return $this->fetchAutoResponderSettings( "first_name" );
		}

		/**
		 * @return mixed
		 */
		public function getAutoResponderLastName() {
			return $this->fetchAutoResponderSettings( "last_name" );
		}

		/**
		 * @return mixed
		 */
		public function getAutoResponderEmail() {
			return $this->fetchAutoResponderSettings( "email" );
		}

		/********************************** Email Settings *********************************/
		public function getSmtpHost() {
			return $this->fetchEmailSettings( "smtp_host" );
		}

		/**
		 * @return mixed
		 */
		public function getSmtpPort() {
			return $this->fetchEmailSettings( "smtp_port" );
		}

		/**
		 * @return mixed
		 */
		public function getSmtpUsername() {
			return $this->fetchEmailSettings( "smtp_username" );
		}

		/**
		 * @return mixed
		 */
		public function getSmtpPassword() {
			return $this->fetchEmailSettings( "smtp_password" );
		}

		/**
		 * @return mixed
		 */
		public function getFrom() {
			return $this->fetchEmailSettings( "from" );
		}

		/**
		 * @return mixed
		 */
		public function getFromEmail() {
			return $this->fetchEmailSettings( "from_email" );
		}

		/**
		 * @return mixed
		 */
		public function getProtocol() {
			return $this->fetchEmailSettings( "protocol" );
		}

		/************************** Payment Integratioin Options **************************/
		public function getPaypalEmail() {
			return $this->fetchPaymentInregration( "paypal_email" );
		}

		/**
		 * @return mixed
		 */
		public function getStripePublishableKey() {
			return $this->fetchPaymentInregration( "stripe_publishable_key" );
		}

		/******************************* Training Materials *******************************/
		public function isTrainingEnabled() {
			return $this->fetchTrainingMaterials( "training_enabled" );
		}

		/**
		 * @return mixed
		 */
		public function getTrainingHTML() {
			return $this->fetchTrainingMaterials( "html" );
		}

		/**
		 * @return mixed
		 */
		public function getTrainingVideos() {
			return $this->fetchTrainingMaterials( "videos" );
		}

		/**
		 * @return mixed
		 */
		public function getTrainingFiles() {
			return $this->fetchTrainingMaterials( "files" );
		}

		/******************************* White Label Options *******************************/
		public function getProductName() {
			return $this->fetchWhiteLabelOptions( "product_name" );
		}

		/**
		 * @return mixed
		 */
		public function getCurrency() {
			return $this->fetchWhiteLabelOptions( "currency" );
		}

		/**
		 * @return mixed
		 */
		public function getProductLogo() {
			return $this->fetchWhiteLabelOptions( "logo" );
		}

		/**
		 * @return mixed
		 */
		public function getProductFooter() {
			return $this->fetchWhiteLabelOptions( "footer_text" );
		}

		/**
		 * @return mixed
		 */
		public function getSupportEmail() {
			return $this->fetchWhiteLabelOptions( "support_email" );
		}

		/**
		 * @return mixed
		 */
		public function getWhiteLabelPackages() {
			return $this->fetchWhiteLabelPackages();
		}

		/******************************* Fetch Functions *******************************/
		private function fetchRebranderAppOptions( $field ) {
			return $this->fetchOptions( $field, "rebrander_app_options" );
		}

		/**
		 * @param $field
		 *
		 * @return mixed
		 */
		private function fetchAppOptions( $field ) {
			return $this->fetchOptions( $field, "app", $field );
		}

		/**
		 * @param $field
		 *
		 * @return mixed
		 */
		private function fetchAutoResponderSettings( $field ) {
			return $this->fetchOptions( $field, "auto_responder_settings" );
		}

		/**
		 * @param $field
		 *
		 * @return mixed
		 */
		private function fetchEmailSettings( $field ) {
			return $this->fetchOptions( $field, "email_settings" );
		}

		/**
		 * @param $field
		 *
		 * @return mixed
		 */
		private function fetchPaymentInregration( $field ) {
			return $this->fetchOptions( $field, "payment_integration" );
		}

		/**
		 * @param $field
		 *
		 * @return mixed
		 */
		private function fetchTrainingMaterials( $field ) {
			return $this->fetchOptions( $field, "training_materials" );
		}

		/**
		 * @param $field
		 *
		 * @return mixed
		 */
		private function fetchWhiteLabelOptions( $field ) {
			return $this->fetchOptions( $field, "white_label_options" );
		}

		/**
		 * @return mixed
		 */
		private function fetchWhiteLabelPackages() {
			return $this->fetchOptions( "white_label_packages", "white_label_options" );
		}

		/**
		 * @param $field
		 *
		 * @return mixed
		 */
		private function fetchOptions( $field, $group ) {
			$white_label = $this->getOptions();
			if( !$white_label ) {
				$white_label = $this->options = $this->send( "all" );
			}
			if( is_null( $field ) ) {
				return $white_label->$group;
			}
			if( isset( $white_label->$group->$field ) ) {
				return $white_label->$group->$field;
			}

			return null;
		}

		/**************************************/
		/**
		 * @param array $post
		 *
		 * @return mixed
		 * @throws Exception
		 */
		public function process( array $post ) {
			return $this->send( "process", $post );
		}

		/**
		 * @param $app_id
		 * @param $first_name
		 * @param $last_name
		 * @param $email
		 *
		 * @return mixed
		 * @throws Exception
		 */
		public function getARForm( $app_id, $first_name, $last_name, $email ) {
			return $this->send( "getarform", array( "id" => $app_id, "first_name" => $first_name, "last_name" => $last_name, "email" => $email ) );
		}

		/***************************** Extended API Functions - External Payment Gateways *****************************/
		public function addClient() {
			$func_vars = func_get_args();
			if( is_array( $func_vars[ 0 ] ) ) {
				$vars = $func_vars[ 0 ];
			} else {
				$vars = array();
				if( isset( $func_vars[ 0 ] ) ) {
					$vars[ "first_name" ] = $func_vars[ 0 ];
				}
				if( isset( $func_vars[ 1 ] ) ) {
					$vars[ "last_name" ] = $func_vars[ 1 ];
				}
				if( isset( $func_vars[ 2 ] ) ) {
					$vars[ "email" ] = $func_vars[ 2 ];
				}
				if( isset( $func_vars[ 2 ] ) ) {
					$vars[ "password" ] = $func_vars[ 3 ];
				}
			}

			return $this->send( "addclient", $vars );
		}

		/**
		 * @return mixed
		 * @throws Exception
		 */
		public function getClient() {
			$func_vars = func_get_args();
			if( is_array( $func_vars[ 0 ] ) ) {
				$vars = $func_vars[ 0 ];
			} else {
				$vars = array();
				if( isset( $func_vars[ 0 ] ) ) {
					$vars[ "email"] = $func_vars[ 0 ];
				}
			}

			return $this->send( "getclient", $vars );
		}

		/**
		 * @return mixed
		 * @throws Exception
		 */
		public function activateClient() {
			$func_vars = func_get_args();
			if( is_array( $func_vars[ 0 ] ) ) {
				$vars = $func_vars[ 0 ];
			} else {
				$vars = array();
				if( isset( $func_vars[ 0 ] ) ) {
					$vars[ "email"] = $func_vars[ 0 ];
				}
			}

			return $this->send( "activateclient", $vars );
		}

		/**
		 * @return mixed
		 * @throws Exception
		 */
		public function suspendClient() {
			$func_vars = func_get_args();
			if( is_array( $func_vars[ 0 ] ) ) {
				$vars = $func_vars[ 0 ];
			} else {
				$vars = array();
				if( isset( $func_vars[ 0 ] ) ) {
					$vars[ "email"] = $func_vars[ 0 ];
				}
			}

			return $this->send( "suspendclient", $vars );
		}

		/**
		 * @return mixed
		 * @throws Exception
		 */
		public function clientStatus() {
			$vars = func_get_args();
			if( is_array( $vars[ 0 ] ) ) {
				$vars = $vars[ 0 ];
			} else {
				$vars = array();
				if( isset( $vars[ 0 ] ) ) {
					$vars[ "email"] = $vars[ 0 ];
				}
			}

			return $this->send( "clientstatus", $vars );
		}

		public function getRebrander() {
			return $this->send("getrebrander", []);
		}

		/********************************************************************************************************************/
		/**
		 * @param $command
		 * @param $params
		 *
		 * @return mixed
		 * @throws Exception
		 */
		private function send( $command, $params = array(), $succcess_only = true ) {
			$this->command = $command;
			$this->params  = $params;
			$result        = $this->curl->send( $command, $params );
			//        var_dump($result);
			switch( $this->curl->getContentType() ) {
				case "application/json":
					$r1     = $result;
					$result = json_decode( $r1 );
					if( is_null( $result ) ) {
						throw new Exception( "Received null response from server: ".$r1, 0 );
					}
					if( isset( $result->error ) ) {
						throw new Exception( $result->error, $result->code );
					}
					if( $succcess_only && isset( $result->data ) ) {
						return $result->data;
					}
					if( isset( $result->success ) ) {
						return true;
					}
					break;
				default:
					return $result;
					break;
			}

			return false;
		}
	}

	// Start rebrander sdk
	/** @var  $rebranderSDK */
	$rebranderSDK = new RebranderSDK();