<?php
	@ob_implicit_flush( 1 );

	if( !class_exists( "ZipArchive" ) ) {
		echo "<h3>ERROR - PHP ZipArchive Library not found!</h3>";
		echo "<p>The Automatic update feature requires the PHP ZipArchive library to be installed. Please ask you system administrator or hosting provider to install it on your hosting server.</p>";
		echo "<p>If it's not possible to install ZipArchive on your server, then you may update software manually by downloading the new version from RebrandApps.com, extracting the zip file to your computer and then manually uploading the extracted files to your server. You may safely overwrite all the files - it won't damage the software or your data.</p>";
		die();
	}

	include( "RebranderSDK.php" );
	require_once( __DIR__."/../checkout/include/functions.php" );

	function removeFile( $file ) {
		try {
			unlink( $file );
		} catch( Exception $e ) {
			echo "WARNING: Could not delete temporary archive - ".$e->getMessage()."<br />";
		}
	}

	$rebrandSDK = new RebranderSDK();

	try {
		$current_path = __DIR__;
		$app_path     = "{$current_path}/../";
		$files        = new RecursiveIteratorIterator( new RecursiveDirectoryIterator( $app_path ), RecursiveIteratorIterator::SELF_FIRST );
		foreach( $files as $file ) {
			$file = str_replace( '\\', '/', $file );
			// Ignore "." and ".." folders
			if( in_array( substr( $file, strrpos( $file, '/' ) + 1 ),
					array(
						'.',
						'..'
					) ) || strpos( $file, "_backup" ) !== false
			) {
				continue;
			}
			if( !is_writable( $file ) ) {
				throw new Exception( "File permission / ownership issues encountered. Please download the package manually.", 100 );
			}
		}

		$temp_path = "{$current_path}/temp";

		if( !is_dir( $temp_path ) ) {
			try {
				mkdir( $temp_path );
			} catch( Exception $e ) {
				die( "Could not create temporary location for file extraction ({$temp_path}). Automatic upgrade aborted!" );
			}
		}

		$file = "{$temp_path}/update.zip";
		file_put_contents( $file, $rebrandSDK->downloadNewVersion() );

		try {
			$zip = new ZipArchive;

			$res = $zip->open( $file, ZipArchive::CHECKCONS );
			if( $res !== true ) {
				switch( $res ) {
					case ZipArchive::ER_NOZIP:
						throw new Exception( "Not a valid zip archive" );
						break;

					case ZipArchive::ER_INCONS:
						throw new Exception( "Zip consistency check failed" );
						break;

					case ZipArchive::ER_CRC:
						throw new Exception( "Zip checksum failed" );
						break;
					default:
						throw new Exception( "Unknown zip error ({$res})" );
						break;
				}
			}
		} catch( Exception $e ) {
			removeFile( $file );
			die( $e->getMessage() );
		}

		try {
			if(!$zip->extractTo( $app_path )) {
				throw new Exception("Unable to extract archive. " . $zip->getStatusString());
			}
			$zip->close();
		} catch( Exception $e ) {
			removeFile( $file );
			die( $e->getMessage() );
		}

		removeFile( $file );
		$site_url = preg_replace( "%rebrander-sdk/?%", "", siteURL( true, true, false, true ) );

		echo "Update successful. <br /><a href='".$site_url."'>Back</a>";
	} catch( Exception $e ) {
		switch( $e->getCode() ) {
			case 100:
				die( $e->getMessage() );
				break;
		}
	}